#!/bin/sh
#
# Component: repositoryhandler
#
# Description:
#   Prints directory location for a user or group.
#
#

if [ -z "${REPOSITORY_USERS}" ] ; then
	. $HOME/etc/setenv.sh

	if [ -z "${REPOSITORY_USERS}" ] ; then
		echo "Environment variable REPOSITORY_USERS is unset" >&2
		exit 1
	fi
fi

function usage_() {
	local BaseName=$( basename "$0" )
	local Ndx

	cat <<- EOFUSAGE
		Usage:
		     ${BaseName} [-h] { -u <user id> | -g <group id> }

		          -h             : prints this help
		          -u <user id>   : prints the path to the user directory of this user
		          -g <group id>  : prints the path to the user directory of this group

		Exit code:
		          0     : the user or group was found in the repository
		          4     : the user or group does not exist in the repository
		          other : error, the directory could not be returned (conflicts, or repository error)
	EOFUSAGE

	if [ -n "$1" ] ; then
		echo >&2
		echo "$@" >&2
		exit 1
	fi

	exit 0
}


User=""

while getopts ':hg:u:' OPT; do
	case $OPT in
		h) usage_ ;;
		g) User="#${OPTARG}" ;;
		u) User="${OPTARG}" ;;
		*) usage_ "Unrecognized option: -${OPTARG}"
	esac
done

[ -z "${User}" ] && usage_ "Missing mandatory option '-u <user id>' or '-g <group id>'"

$REPOSITORY_HANDLER_HOME/bin/locateResource "${REPOSITORY_USERS}" "${User}"

